#################################################################
#                                                               #
# Analysis for "What would disprove interdependence?            #
#   Lessons learned from a study on biliteracy in Portuguese    #
#   heritage language speakers in Switzerland"                  #
#                                                               #
# Raphael Berthele (raphael.berthele@unifr.ch)                  #
# Jan Vanhove (jan.vanhove@unifr.ch)                            #
#                                                               #
#################################################################

#----------------------------------------------------------------
# Load packages

library(tidyverse) # for working with dataframes
library(cowplot)   # additional plotting functionality
library(lme4)      # mixed-effects modelling

#----------------------------------------------------------------
# Set plotting theme

theme_set(theme_cowplot(11))

#----------------------------------------------------------------
# Read in and recode data

# Two arrangments of same data
reading_melt <- read.csv("Data/reading_melt.csv")
reading2_23 <- read.csv("Data/reading2_23.csv")

# Code Time as factor
reading_melt$Time <- factor(reading_melt$Time)
reading2_23$Time <- factor(reading2_23$Time)

# Multiply all values by 100 (percentages rather than proportions)
reading_melt$value <- 100 * reading_melt$value
reading2_23$value <- 100 * reading2_23$value
reading2_23$PreviousOther <- 100 * reading2_23$PreviousOther
reading2_23$PreviousSame <- 100 * reading2_23$PreviousSame
reading2_23$PreviousSchool <- 100 * reading2_23$PreviousSchool
reading2_23$PreviousPortuguese <- 100 * reading2_23$PreviousPortuguese

# More comprehensible labels for the language groups
reading_melt$BilingualControl2 <- reading_melt$LanguageGroup2
levels(reading_melt$BilingualControl2) <- c("bilingual (French)", 
                                            "bilingual (German)", 
                                            "comparison", 
                                            "comparison", 
                                            "comparison")

#----------------------------------------------------------------
# Figure 1: Boxplot reading comprehension scores

language_names <- c(
  `French` = "tested in French",
  `German` = "tested in German",
  `Portuguese` = "tested in Portuguese"
)

# function for number of observations 
give.n <- function(x, add = 3){
  return(c(y = median(x) + add, label = length(x))) 
  # experiment with the add parameter to find the perfect position
}

ggplot(reading_melt, aes(Time, value, fill = BilingualControl2)) +
  geom_boxplot(outlier.shape = 1) +
  facet_wrap(~ LanguageTested2, 
             labeller = as_labeller(language_names)) +
  stat_summary(fun.data = give.n, geom = "text", 
               fun.y = median, size = 2.5,
               position = position_dodge(width = 0.75)) +
  xlab("Time of data collection") +
  ylab("Reading score") +
  theme(legend.direction = "horizontal", 
        legend.position = "bottom",
        strip.text.x = element_text(size = 11),
        panel.grid = element_blank(),
        panel.grid.major.y = element_line(colour = "grey90"),
        axis.text = element_text(colour = "black")) + 
  scale_fill_grey(start = 0.4, end = 1) +
  labs(fill = "Bilingual vs. comparison")

#----------------------------------------------------------------
# Figure 2: Scatterplot with school language on x-axis

theme_set(theme_bw(10))
labels <- c(
  `French` = "tested in French",
  `German` = "tested in German",
  `Portuguese` = "tested in Portuguese",
  `Bilingual group (French)` = "Bilingual group (French)",
  `Bilingual group (German)` = "Bilingual group (German)",
  `2` = "T1-T2",
  `3` = "T2-T3"
)

p <- ggplot(reading2_23, aes(x = PreviousSchool, y = value)) +
  geom_point(shape = 1, position = position_jitter(0.8, 0.8)) +
  stat_smooth(method = "lm", se = FALSE, colour = "black") +
  facet_grid(Time ~ LanguageGroup2 + LanguageTested2, 
             labeller = as_labeller(labels)) +
  ylab("Reading comprehension score") +
  xlab("Previous score: School language") +
  ggtitle("Reading comprehension score depending on previous school language score\n(participant group by time)") +
  theme(legend.direction = "horizontal", 
        legend.position = "bottom",
        strip.text.x = element_text(size = 11), 
        strip.text.y = element_text(size = 11),
        panel.grid = element_blank(),
        axis.text = element_text(colour = "black"))

# Compute correlations/n
n_r_reading_School <- summarise(group_by(reading2_23, Time, LanguageGroup2, LanguageTested2),
                                r = format(round(cor(PreviousSchool, value, use = "p"), 2), nsmall = 2),
                                n = length(PreviousPortuguese[!is.na(PreviousSchool) & !is.na(value)]))
# Combine both numbers into a text string
n_r_reading_School$Label <- paste("n = ", as.character(n_r_reading_School$n), ", r = ", as.character(n_r_reading_School$r), sep = "")
# Add x/y positions for text labels
n_r_reading_School$x <- 100; n_r_reading_School$y <- 0

# Draw graph
p + geom_text(aes(x, y, label = Label, group = NULL), 
              hjust = 1, vjust = 0, # vertical/horizontal adjustment for labels
              size = 4,
              data = n_r_reading_School)

#----------------------------------------------------------------
# Figure 3: Scatterplot with heritage language on x-axis

theme_set(theme_bw(10))
p <- ggplot(reading2_23, aes(x = PreviousPortuguese, y = value)) +
  geom_point(shape = 1, position = position_jitter(width = 0.8, height = 0.8)) +
  stat_smooth(method = "lm", se = FALSE, colour = "black") +
  facet_grid(Time ~ LanguageGroup2 + LanguageTested2, 
             labeller = as_labeller(labels)) +
  ylab("Reading comprehension score") +
  xlab("Previous score: Portuguese") +
  ggtitle("Reading comprehension score depending on previous Portuguese score\n(participant group by time)") +
  theme(legend.direction = "horizontal", 
        legend.position = "bottom",
        strip.text.x = element_text(size = 11), 
        strip.text.y = element_text(size = 11),
        panel.grid = element_blank(),
        axis.text = element_text(colour = "black"))

# Compute correlations/n
n_r_reading_Port <- summarise(group_by(reading2_23, Time, LanguageGroup2, LanguageTested2),
                              r = format(round(cor(PreviousPortuguese, value, use = "p"), 2), nsmall = 2),
                              n = length(PreviousPortuguese[!is.na(PreviousPortuguese) & !is.na(value)]))
# Combine both numbers into a text string
n_r_reading_Port$Label <- paste("n = ", as.character(n_r_reading_Port$n), ", r = ", as.character(n_r_reading_Port$r), sep = "")
# Add x/y positions for text labels
n_r_reading_Port$x <- 100; n_r_reading_Port$y <- 0

# Draw graph
p + geom_text(aes(x, y, label = Label, group = NULL), 
              hjust = 1, vjust = 0, # vertical/horizontal adjustment for labels
              size = 4,
              data = n_r_reading_Port)

#----------------------------------------------------------------
# Mixed model analyses

# Retain only variables of interest
reading2_23_complete <- reading2_23 %>% 
  select(VPNID, Class, Time, LanguageTested, LanguageGroup2,
         PreviousSame, PreviousOther,
         value)
reading2_23_complete <- reading2_23_complete[complete.cases(reading2_23_complete), ]

# Centre or sum-code variables
reading2_23_complete$n.Time <- as.numeric(reading2_23_complete$Time) - 1.5
reading2_23_complete$n.HL <- as.numeric(reading2_23_complete$LanguageTested) - 1.5
reading2_23_complete$n.German <- as.numeric(reading2_23_complete$LanguageGroup2) - 1.5
reading2_23_complete$c.PreviousSame <- (reading2_23_complete$PreviousSame - mean(reading2_23_complete$PreviousSame))/100
reading2_23_complete$c.PreviousOther <- (reading2_23_complete$PreviousOther - mean(reading2_23_complete$PreviousOther))/100
reading2_23_complete$value <- reading2_23_complete$value/100
# Dividing PreviousSame and PreviousOther by 100 again works better (better convergence).

# FIRST PREDICTION

# Null model for first prediction
reading.lmer1 <- lmer(value ~ n.Time + n.HL*n.German + 
                        c.PreviousSame +
                        (1|VPNID) + (1 + n.Time + c.PreviousSame + c.PreviousOther + n.HL | Class),
                      data = reading2_23_complete)

# add FE for PreviousOther
reading.lmer2 <- lmer(value ~ n.Time + n.HL*n.German + 
                        c.PreviousSame + c.PreviousOther +
                        (1|VPNID) + (1 + n.Time + c.PreviousSame + c.PreviousOther + n.HL | Class),
                      data = reading2_23_complete)

# Model comparison: X²(1) = 10.7, p = 0.001
anova(reading.lmer1, reading.lmer2)

# Estimates of beta coefficients:
summary(reading.lmer2)


# SECOND PREDICTION

# L1-to-L2 vs. L2-to-L1 effects
reading.lmer3 <- lmer(value ~ n.Time + n.HL*n.German +
                        c.PreviousSame + c.PreviousOther*n.HL +
                        (1|VPNID) + (1 + n.Time + c.PreviousSame + c.PreviousOther + n.HL | Class),
                      data = reading2_23_complete)
anova(reading.lmer2, reading.lmer3) # X² = 0.64, p = 0.42

# THIRD PREDICTION

reading.lmer4 <- lmer(value ~ n.Time + n.HL*n.German +
                        c.PreviousSame + c.PreviousOther*n.German +
                        (1|VPNID) + (1 + n.Time + c.PreviousSame + c.PreviousOther + n.HL | Class),
                      data = reading2_23_complete)
anova(reading.lmer2, reading.lmer4) # X² = 0.01, p = 0.93

# Follow-up analyses typological effect
# Interaction between PreviousOther, LanguageGroup2 and Time:
reading.lmer5 <- lmer(value ~ n.Time + n.HL*n.German +
                        c.PreviousSame + c.PreviousOther*n.German*n.Time +
                        (1|VPNID) + (1 + n.Time + c.PreviousSame + c.PreviousOther + n.HL | Class),
                      data = reading2_23_complete)
reading.lmer5_null <- lmer(value ~ n.Time + n.HL*n.German +
                             c.PreviousSame + c.PreviousOther*n.German + c.PreviousOther*n.Time + n.Time*n.German +
                             (1|VPNID) + (1 + n.Time + c.PreviousSame + c.PreviousOther + n.HL | Class),
                           data = reading2_23_complete)
anova(reading.lmer5, reading.lmer5_null) # X² = 10.2, p = 0.001.

# END --------------------------------------------------------------------------------------------------------------